@@ -1,5 +1,5 @@
 /*
- * $Id: muxpect.c,v 1.2 1999/08/16 00:25:10 trockij Exp $
+ * $Id: muxpect.c,v 1.2.2.1 1999/09/14 17:39:21 trockij Exp $
  */
 
 /*
@@ -51,7 +51,8 @@ main (int argc, char **argv)
     optind = 0;
     port = 0;
 
-    while ((c = getopt (argc, argv, "dhf:p:")) != EOF) {
+    while ((c = getopt (argc, argv, "dhf:p:")) != EOF)
+    {
 	switch (c) {
 	    case 'h':
 		help++;
@@ -79,7 +80,8 @@ main (int argc, char **argv)
      */
     sess = read_expect (fname);
 
-    if (sess == NULL) {
+    if (sess == NULL)
+    {
 	fprintf (stderr, "could not read\n");
 	exit (1);
     }
@@ -92,7 +94,8 @@ main (int argc, char **argv)
 		sess,
 		port,
 		errbuf,
-		sizeof(errbuf)) == NULL) {
+		sizeof(errbuf)) == NULL)
+    {
 	printf ("could not setup sessions: %s\n", errbuf);
 	exit (-1);
     }
@@ -115,7 +118,8 @@ match_buffer (regex_t *preg,
 
     r = regcomp (preg, pat, REG_EXTENDED | REG_ICASE | REG_NOSUB);
 
-    if (r) {
+    if (r)
+    {
 	regerror (r, preg, errbuf, errbuflen);
 	fprintf (stderr, "error in regcomp: %s\n", errbuf);
 	exit (1);
@@ -123,9 +127,13 @@ match_buffer (regex_t *preg,
     
     r = regexec (preg, buf, 0, 0, 0);
     
-    if (r == REG_NOMATCH) {
+    if (r == REG_NOMATCH)
+    {
 	fprintf (stderr, "no match\n");
-    } else if (r != REG_NOERROR) {
+
+    }
+    else if (r != REG_NOERROR)
+    {
 	regerror (r, preg, errbuf, errbuflen);
 	fprintf (stderr, "error in regexec: %s\n", errbuf);
 	return (-1);
